pm4py.evaluation.generalization package
=======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.generalization.variants

Submodules
----------

pm4py.evaluation.generalization.evaluator module
------------------------------------------------

.. automodule:: pm4py.evaluation.generalization.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.evaluation.generalization.parameters module
-------------------------------------------------

.. automodule:: pm4py.evaluation.generalization.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.generalization
   :members:
   :undoc-members:
   :show-inheritance:
